commit 6215a1e8a0b67b7a78d0fa3d7f23b72ad11e4951
Author: Albrecht Schlosser <AlbrechtS.fltk@gmail.com>
Date:   Fri Jul 15 15:53:03 2016 +0200

    Fix MinGW build, remove warning (unused variable).

diff --git a/fluid/ExternalCodeEditor_WIN32.cxx b/fluid/ExternalCodeEditor_WIN32.cxx
index afa269a..767fd81 100644
--- a/fluid/ExternalCodeEditor_WIN32.cxx
+++ b/fluid/ExternalCodeEditor_WIN32.cxx
@@ -105,7 +105,6 @@ static BOOL CALLBACK terminate_app_enum(HWND hwnd, LPARAM lParam) {
 // Wait up to msecTimeout for process to close, and if it doesn't, use TerminateProcess().
 //
 static int terminate_app(DWORD pid, DWORD msecTimeout) {
-  DWORD   dwRet ;
   HANDLE hProc = OpenProcess(SYNCHRONIZE|PROCESS_TERMINATE, FALSE, pid);
   if ( !hProc ) return -1;
   // terminate_app_enum() posts WM_CLOSE to all windows matching pid
@@ -397,8 +396,8 @@ int ExternalCodeEditor::start_editor(const char *editor_cmd,
                     (char*)cmd,         // command to exec
                     NULL,               // secure attribs
                     NULL,               // thread secure attribs
-                    NULL,               // handle inheritence
-                    NULL,               // creation flags
+                    FALSE,              // handle inheritance
+                    0,                  // creation flags
                     NULL,               // environ block
                     NULL,               // current dir
                     &sinfo,             // startup info
diff --git a/fluid/ExternalCodeEditor_WIN32.h b/fluid/ExternalCodeEditor_WIN32.h
index 9183dd9..43492e6 100644
--- a/fluid/ExternalCodeEditor_WIN32.h
+++ b/fluid/ExternalCodeEditor_WIN32.h
@@ -9,6 +9,21 @@
 #ifndef _EXTCODEEDITOR_H
 #define _EXTCODEEDITOR_H
 
+/* We require at least Windows 2000 (WINVER == 0x0500) for GetFileSizeEx().  */
+/* This must be defined before #include <windows.h> - MinGW doesn't do that. */
+#if !defined(WINVER) || (WINVER < 0x0500)
+# ifdef WINVER
+#  undef WINVER
+# endif
+# define WINVER 0x0500
+#endif
+#if !defined(_WIN32_WINNT) || (_WIN32_WINNT < 0x0500)
+# ifdef _WIN32_WINNT
+#  undef _WIN32_WINNT
+# endif
+# define _WIN32_WINNT 0x0500
+#endif
+
 #include <windows.h>                /* CreateFile().. */
 #include <string.h>                 /* sprintf().. */
 
